"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const ArchiveCommand_1 = require("../../archive/ArchiveCommand");
const WebConsoleArchiveHandler_1 = require("../../archive/WebConsoleArchiveHandler");
const StepServiceRepository_1 = require("../../acl/stepService/StepServiceRepository");
const StepConsoleRepository_1 = require("../../archive/StepConsoleRepository");
const StepletConsoleRepository_1 = require("../../archive/StepletConsoleRepository");
jest.mock('@jfrog-pipelines/configuration', () => {
    return {
        ConfigFactory: { config: { apiToken: 'apitoken' } }
    };
});
jest.mock('@jfrog-pipelines/logger', () => {
    const actualTracker = jest.requireActual('@jfrog-pipelines/logger');
    return {
        ...actualTracker,
        Log: jest.fn(),
        LoggerFactory: {
            getLogger: jest.fn().mockReturnValue({
                info: jest.fn(),
                error: jest.fn(),
                debug: jest.fn(),
                trace: jest.fn(),
                warn: jest.fn()
            }),
            configure: jest.fn(),
            getEventLogger: jest.fn().mockReturnValue({
                info: jest.fn(),
                error: jest.fn(),
                debug: jest.fn(),
                trace: jest.fn(),
                warn: jest.fn()
            }),
            logEvent: jest.fn()
        }
    };
});
describe('delete log consoles', () => {
    it('should delete consoles', async () => {
        const stepId = 1;
        const type = 'step';
        const deleteQuery = {
            where: {
                stepId: stepId
            }
        };
        const stepMock = {
            isConsoleArchived: true
        };
        const stepletMock = [
            {
                id: 1,
                isConsoleArchived: true
            },
            {
                id: 2,
                isConsoleArchived: true
            }
        ];
        const archiveCommand = new ArchiveCommand_1.ArchiveCommand(type, stepId);
        const webConsoleArchiveHandler = new WebConsoleArchiveHandler_1.WebConsoleArchiveCommandHandler();
        const getStepServiceRepositorySpy = jest
            .spyOn(StepServiceRepository_1.StepServiceRepository.prototype, 'getStepById')
            .mockResolvedValue(stepMock);
        const deleteStepServiceRepositorySpy = jest
            .spyOn(StepConsoleRepository_1.StepConsoleRepository.prototype, 'delete')
            .mockResolvedValueOnce(1);
        const getStepletsByStepIdSpy = jest
            .spyOn(StepServiceRepository_1.StepServiceRepository.prototype, 'getStepletsByStepId')
            .mockResolvedValue(stepletMock);
        const deleteStepletConsoleSpy = jest.spyOn(StepletConsoleRepository_1.StepletConsoleRepository.prototype, 'delete').mockResolvedValue(1);
        await webConsoleArchiveHandler.handle(archiveCommand);
        expect(getStepServiceRepositorySpy).toHaveBeenCalledWith(stepId);
        expect(deleteStepServiceRepositorySpy).toHaveBeenCalledWith(deleteQuery);
        expect(getStepletsByStepIdSpy).toHaveBeenCalledWith(stepId);
        expect(deleteStepletConsoleSpy).toHaveBeenCalledTimes(stepletMock.length);
    });
    it('should not delete step console but delete steplet console', async () => {
        const stepId = 1;
        const type = 'step';
        const stepMock = {
            isConsoleArchived: false
        };
        const stepletMock = [
            {
                id: 1,
                isConsoleArchived: true
            },
            {
                id: 2,
                isConsoleArchived: true
            }
        ];
        const archiveCommand = new ArchiveCommand_1.ArchiveCommand(type, stepId);
        const webConsoleArchiveHandler = new WebConsoleArchiveHandler_1.WebConsoleArchiveCommandHandler();
        const getStepServiceRepositorySpy = jest
            .spyOn(StepServiceRepository_1.StepServiceRepository.prototype, 'getStepById')
            .mockResolvedValue(stepMock);
        const deleteStepServiceRepositorySpy = jest
            .spyOn(StepConsoleRepository_1.StepConsoleRepository.prototype, 'delete')
            .mockResolvedValue(stepId);
        const getStepletsByStepIdSpy = jest
            .spyOn(StepServiceRepository_1.StepServiceRepository.prototype, 'getStepletsByStepId')
            .mockResolvedValue(stepletMock);
        const updateStepSpy = jest
            .spyOn(StepServiceRepository_1.StepServiceRepository.prototype, 'updateStep')
            .mockResolvedValueOnce({});
        const deleteStepletConsoleSpy = jest.spyOn(StepletConsoleRepository_1.StepletConsoleRepository.prototype, 'delete').mockResolvedValue(1);
        const archiveStepSpy = jest
            .spyOn(WebConsoleArchiveHandler_1.WebConsoleArchiveCommandHandler.prototype, 'archiveStep')
            .mockImplementationOnce(jest.fn());
        await webConsoleArchiveHandler.handle(archiveCommand);
        expect(getStepServiceRepositorySpy).toHaveBeenCalledWith(stepId);
        expect(deleteStepServiceRepositorySpy).toHaveBeenCalledTimes(1);
        expect(getStepletsByStepIdSpy).toHaveBeenCalledWith(stepId);
        expect(archiveStepSpy).toHaveBeenCalledTimes(1);
        expect(updateStepSpy).toHaveBeenCalledWith(stepId, { isConsoleArchived: true });
        expect(deleteStepletConsoleSpy).toHaveBeenCalledTimes(stepletMock.length);
    });
    it('should delete step console and delete one steplet console', async () => {
        const stepId = 1;
        const type = 'step';
        const deleteQuery = {
            where: {
                stepId: stepId
            }
        };
        const stepMock = {
            isConsoleArchived: true
        };
        const stepletMock = [
            {
                id: 1,
                isConsoleArchived: false
            },
            {
                id: 2,
                isConsoleArchived: true
            }
        ];
        const archiveCommand = new ArchiveCommand_1.ArchiveCommand(type, stepId);
        const webConsoleArchiveHandler = new WebConsoleArchiveHandler_1.WebConsoleArchiveCommandHandler();
        const getStepServiceRepositorySpy = jest
            .spyOn(StepServiceRepository_1.StepServiceRepository.prototype, 'getStepById')
            .mockResolvedValue(stepMock);
        const deleteStepServiceRepositorySpy = jest
            .spyOn(StepConsoleRepository_1.StepConsoleRepository.prototype, 'delete')
            .mockResolvedValueOnce(1);
        const getStepletsByStepIdSpy = jest
            .spyOn(StepServiceRepository_1.StepServiceRepository.prototype, 'getStepletsByStepId')
            .mockResolvedValue(stepletMock);
        const deleteStepletConsoleSpy = jest.spyOn(StepletConsoleRepository_1.StepletConsoleRepository.prototype, 'delete').mockResolvedValue(1);
        await webConsoleArchiveHandler.handle(archiveCommand);
        expect(getStepServiceRepositorySpy).toHaveBeenCalledWith(stepId);
        expect(deleteStepServiceRepositorySpy).toHaveBeenCalledWith(deleteQuery);
        expect(getStepletsByStepIdSpy).toHaveBeenCalledWith(stepId);
        expect(deleteStepletConsoleSpy).toHaveBeenCalledTimes(1);
    });
    it('should not delete step console and steplet console', async () => {
        const stepId = 1;
        const type = 'step';
        const stepMock = {
            isConsoleArchived: false
        };
        const stepletMock = [
            {
                id: 1,
                isConsoleArchived: false
            },
            {
                id: 2,
                isConsoleArchived: false
            }
        ];
        const archiveCommand = new ArchiveCommand_1.ArchiveCommand(type, stepId);
        const webConsoleArchiveHandler = new WebConsoleArchiveHandler_1.WebConsoleArchiveCommandHandler();
        const getStepServiceRepositorySpy = jest
            .spyOn(StepServiceRepository_1.StepServiceRepository.prototype, 'getStepById')
            .mockResolvedValue(stepMock);
        const deleteStepServiceRepositorySpy = jest
            .spyOn(StepConsoleRepository_1.StepConsoleRepository.prototype, 'delete')
            .mockResolvedValueOnce(1);
        const getStepletsByStepIdSpy = jest
            .spyOn(StepServiceRepository_1.StepServiceRepository.prototype, 'getStepletsByStepId')
            .mockResolvedValueOnce(stepletMock);
        const deleteStepletConsoleSpy = jest.spyOn(StepletConsoleRepository_1.StepletConsoleRepository.prototype, 'delete').mockResolvedValue(1);
        const archiveStepSpy = jest
            .spyOn(WebConsoleArchiveHandler_1.WebConsoleArchiveCommandHandler.prototype, 'archiveStep')
            .mockImplementationOnce(jest.fn());
        const updateStepSpy = jest
            .spyOn(StepServiceRepository_1.StepServiceRepository.prototype, 'updateStep')
            .mockResolvedValueOnce({});
        await webConsoleArchiveHandler.handle(archiveCommand);
        expect(getStepServiceRepositorySpy).toHaveBeenCalledWith(stepId);
        expect(deleteStepServiceRepositorySpy).toHaveBeenCalledTimes(1);
        expect(updateStepSpy).toHaveBeenCalledWith(stepId, { isConsoleArchived: true });
        expect(getStepletsByStepIdSpy).toHaveBeenCalledWith(stepId);
        expect(archiveStepSpy).toHaveBeenCalledTimes(1);
        expect(deleteStepletConsoleSpy).toHaveBeenCalledTimes(0);
    });
});
//# sourceMappingURL=WebConsoleArchiveHandler.test.js.map