"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const node_stream_1 = require("node:stream");
const streams_1 = require("../../streams");
describe('Db Row transformer Test', () => {
    it('Should transform db logs row expected format', async () => {
        const logDate = Date.now();
        let messageWasSend = false;
        const mockEventStream = new node_stream_1.Readable({
            objectMode: true,
            read: function () {
                if (!messageWasSend) {
                    messageWasSend = true;
                    return this.push({ message: 'event', timestamp: logDate, some: 'otherField' });
                }
                return this.push(null);
            }
        });
        const writable = new node_stream_1.Writable({
            objectMode: true,
            write: function (chunk, encoding, next) {
                if (!chunk.startsWith(']')) {
                    const databaseRow = JSON.parse(chunk.startsWith('[') ? chunk.slice(1) : chunk);
                    expect(databaseRow.message).toBe('event');
                    expect(databaseRow.timestamp).toBe(logDate);
                    expect(databaseRow.some).toBe('otherField');
                }
                next();
            }
        });
        mockEventStream.pipe(new streams_1.DbRowTransformer()).pipe(writable);
        await new Promise((resolve) => writable.on('finish', resolve));
    });
});
//# sourceMappingURL=DbRowTransformer.test.js.map