"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.StepConsoleRepository = void 0;
const node_util_1 = require("node:util");
const data_access_layer_1 = require("@jfrog-pipelines/data-access-layer");
const pg_query_stream_1 = __importDefault(require("pg-query-stream"));
const BATCH_SIZE = 1000;
const QUERY_STREAM_CONFIG = { batchSize: BATCH_SIZE };
class StepConsoleRepository extends data_access_layer_1.CrudRepository {
    constructor() {
        super(data_access_layer_1.StepConsole);
        this.dbConnectionManager = null;
        this.dbConnection = null;
    }
    async getByStepId(stepId) {
        const updatedQuery = (0, node_util_1.format)(StepConsoleRepository.GET_BY_STEPID_RAW_QUERY, stepId);
        const databaseConnection = await this.getConnection();
        this.dbConnection = databaseConnection;
        const readableStream = databaseConnection.query(new pg_query_stream_1.default(updatedQuery, [], QUERY_STREAM_CONFIG));
        const releaseConnection = this.releaseConnection();
        readableStream.on(`finish`, () => releaseConnection);
        readableStream.on(`error`, () => releaseConnection);
        readableStream.on(`close`, () => releaseConnection);
        return readableStream;
    }
    releaseConnection() {
        if (this.dbConnection !== null || this.dbConnectionManager !== null) {
            if (this.dbConnectionManager !== null) {
                this.dbConnectionManager.releaseConnection(this.dbConnection);
            }
            this.dbConnection = null;
            this.dbConnectionManager = null;
        }
        return true;
    }
    async getConnection() {
        if (this.dbConnection !== null) {
            return this.dbConnection;
        }
        if (this.dbConnectionManager === null) {
            this.dbConnectionManager = new data_access_layer_1.SequelizeConnectionManager();
        }
        return this.dbConnectionManager.getConnection();
    }
}
exports.StepConsoleRepository = StepConsoleRepository;
StepConsoleRepository.GET_BY_STEPID_RAW_QUERY = `SELECT * FROM "stepConsoles" WHERE "stepId" = %s;`;
//# sourceMappingURL=StepConsoleRepository.js.map